
/*************************************************/
/*                                               */
/*   BFONT 1.1.0 Test example by Diego Billi     */
/*                                               */
/*************************************************/

#include <stdlib.h>
#include <stdio.h>
#include <string.h>

#include <SDL/SDL.h>
#include <SDL/SDL_image.h>

#include "BFont.h"

SDL_Surface *screen;
SDL_Event    event;
int          quit = 0;

int main(int argc, char *argv[])
{
	BFont_Info *Font1=NULL;
	BFont_Info *Font2=NULL;
	BFont_Info *Font3=NULL;

	SDL_Surface *font_file;
	SDL_Surface *surf_text;
	SDL_Rect destpos;

	int h1,h2;

	if (argc < 3) {
		printf("USAGE: Test <font1> <font2>\n");
		exit(1);
	}

	if ( SDL_Init(SDL_INIT_VIDEO) < 0 ) {
		fprintf(stderr,"Couldn't initialize SDL: %s\n", SDL_GetError());
		exit(1);
	}

	atexit(SDL_Quit);

	screen = SDL_SetVideoMode(640, 480, 0, 0);
	if ( screen == NULL ) {
		fprintf(stderr, "Couldn't set %dx%dx%d video mode: %s\n",640, 480,32, SDL_GetError());
		exit(1);
	}

	/* Fill background with some color */
	SDL_FillRect(screen, NULL, SDL_MapRGB(screen->format, 150, 150, 150) );

	/* Load fonts files */
	puts("loading fonts...");


	Font1 = BFont_LoadFont(argv[1]);
	if (Font1 == NULL) {
		fprintf(stderr, "Couldnt load %s\n",argv[1]);
		exit(1);
	}

	/* Load font from Surface */
	font_file = (SDL_Surface *) IMG_Load(argv[2]);
	if (font_file == NULL) {
		fprintf(stderr, "Couldnt load %s file\n",argv[2]);
		exit(1);
	}


	Font2 = BFont_LoadFontFromSurface(font_file);
	if (Font2 == NULL) {
		fprintf(stderr, "Couldnt create %s BFont_Info\n",argv[2]);
		exit(1);
	}


	Font3 = BFont_SetFontColor(Font1,255,0,0);

	/* Get fonts height */
	h1 = BFont_FontHeight(Font1);
	h2 = BFont_FontHeight(Font2);

	/* Set the default font */
	BFont_SetCurrentFont(Font3);

	/* Write different strings with the defaul font */
	BFont_PutString            (screen,  0, 0, "This string is at (0,0).");
	BFont_LeftPutString        (screen,  1*h1, "Left aligned text!");
	BFont_CenteredPutString    (screen,  2*h1, "Centered text!");
	BFont_RightPutString       (screen,  3*h1, "Right aligned text!");
	BFont_JustifiedPutString   (screen,  4*h1, "Fine justified text SSS example!");

	/* Write different strings with a specific font and different arguments :-)*/
	BFont_PrintStringFont          (screen, Font2,0, 4*h2+100, "This string is at (%d,%d)", 0, 4*h2+100);
	BFont_LeftPrintStringFont      (screen, Font2, 5*h2+100, "Left aligned text! %d",10);
	BFont_CenteredPrintStringFont  (screen, Font2, 6*h2+100, "Centered text! %3.2f",3.14);
	BFont_RightPrintStringFont     (screen, Font2, 7*h2+100, "Right aligned text! %d %3.3f",10,666.999);
	BFont_JustifiedPrintStringFont (screen, Font2, 8*h2+100, "Fine justified text example! %s","hello!");


	/* Update all */
	SDL_UpdateRect(screen, 0, 0, 0, 0);


	/* New feature added with 1.0.5 version */

	/* Create a SDL_Surface with a string inside and blit it on the screen */
	surf_text = NULL;
	surf_text = BFont_CreateSurfaceFont(Font3, "Salve Mondo!!!");

	if (surf_text != NULL) 
	{
		/* Blit it on the bottom right corner */
		memset(&destpos, 0, sizeof(SDL_Rect));
		destpos.x = 640 - surf_text->w;
		destpos.y = 480 - surf_text->h;
		destpos.w = surf_text->w;
		destpos.h = surf_text->h;

		SDL_BlitSurface(surf_text, NULL, screen, &destpos);

		/* Update  */
		SDL_UpdateRect(screen, destpos.x, destpos.y, destpos.w, destpos.h);

		/* Free all stuff */
		SDL_FreeSurface(surf_text);
	}


	/* Wait until SDL_QUIT event type (window closed)*/
	while( !quit )
	{
		while( SDL_PollEvent( &event ) )
		{
			switch( event.type )
			{
				case SDL_QUIT:
					quit = 1;
					break;
				default:
					break;
			}
	
		}
	}

	BFont_FreeFont(Font1);
	BFont_FreeFont(Font2);
	BFont_FreeFont(Font3);

	SDL_Quit();

	return 0;
}



